/* $Id */
#if !defined MODULE_H
#define MODULE_H

#if !defined TRUE
#define TRUE !0
#define FALSE 0
#endif /* !TRUE */

enum imageType {
  TYPE_INDEXED, /* Indexed colors */
  TYPE_RGB      /* RGB colors */
};
typedef enum imageType ImageType;

enum disposeOp {
  DISPOSE_OP_NONE,       /* no disposal is done */
  DISPOSE_OP_BACKGROUND, /* to be cleared to fully transparent black */
  DISPOSE_OP_PREVIOUS    /* to be reverted to the previous contents */
};

enum blendOp {
  BLEND_OP_SOURCE, /* overwrite the buffer */
  BLEND_OP_OVER    /* to be composited onto the buffer */
};

typedef struct image Image;
typedef struct imageSet ImageSet;

struct entry {
  const char *filename;
  double display_gamma;
  unsigned short background_red;
  unsigned short background_green;
  unsigned short background_blue;
  unsigned short background_gray;
  int bit_depth;
  int display_width;
  int display_height;
};
typedef struct entry Entry;

int module_read_images(Entry *entry, ImageSet *images, const char *format);

ImageSet *imageSet_new(void);
void imageSet_free(ImageSet *images);
void imageSet_add_image(ImageSet *images, Image *image);
Image *imageSet_get_first(ImageSet *images);
int imageSet_get_nimages(ImageSet *images);
unsigned long imageSet_get_background(ImageSet *images);
void imageSet_get_size(ImageSet *images, int *width, int *height);
void imageSet_set_size(ImageSet *images, int width, int height);
int imageSet_get_num_plays(ImageSet *images);
void imageSet_set_num_plays(ImageSet *images, int num);
void imageSet_set_num_colors(ImageSet *images, int num);
void imageSet_set_color(ImageSet *images, int index, unsigned char r, unsigned char g, unsigned char b, unsigned char a);

Image *image_new(void);
unsigned char *image_get_data(Image *image);
void image_set_data(Image *image, unsigned char *data);
void image_get_size(Image *image, int *width, int *height);
void image_set_size(Image *image, int width, int height);
void image_get_offset(Image *image, int *xoff, int *yoff);
void image_set_offset(Image *image, int xoff, int yoff);
int image_get_num_colors(Image *image);
void image_set_num_colors(Image *image, int num);
void image_get_color(Image *image, int index, unsigned char *r, unsigned char *g, unsigned char *b, unsigned char *a);
void image_set_color(Image *image, int index, unsigned char r, unsigned char g, unsigned char b, unsigned char a);
void image_set_comment(Image *image, const char *comment);
int image_get_delay(Image *image);
void image_set_delay(Image *image, int delay);
int image_get_dispose_op(Image *image);
void image_set_dispose_op(Image *image, int dispose_op);
ImageType image_get_type(Image *image);
void image_set_type(Image *image, ImageType type);
Image *image_next(Image *image);

#endif /* !MODULE_H */
